==> arkhitekton-0.6.1-sources.jar: universum/studios/android/arkhitekton/interaction/ResponseImpl.kt <==
/*
 * *************************************************************************************************
 *                                 Copyright 2018 Universum Studios
 * *************************************************************************************************
 *                  Licensed under the Apache License, Version 2.0 (the "License")
 * -------------------------------------------------------------------------------------------------
 * You may not use this file except in compliance with the License. You may obtain a copy of the
 * License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied.
 *
 * See the License for the specific language governing permissions and limitations under the License.
 * *************************************************************************************************
 */
package universum.studios.android.arkhitekton.interaction

import universum.studios.android.arkhitekton.util.Failure
import universum.studios.android.arkhitekton.util.InstanceBuilder

/**
 * An implementation of [Response].
 *
 * @author Martin Albedinsky
 * @since 1.0
 *
 * @constructor Creates a new instance of ResponseImpl with the given `builder's` configuration.
 * @param builder The builder with configuration for the new response.
 */
internal class ResponseImpl<out Result> internal constructor(builder: Builder<Result>) : Response<Result> {

    /*
     * Companion ===================================================================================
     */

    /**
     */
    companion object {

        /**
         * Log TAG.
         */
        internal const val TAG = "Response"
    }

    /*
	 * Interface ===================================================================================
	 */

    /*
     * Members =====================================================================================
     */

    /**
     * Request associated with this response.
     */
    private val request = builder.request

    /**
     * Result which was produced by successful execution of the associated [request].
     *
     * If this response is a failure, this should be [Result.empty].
     */
    private val result = builder.result

    /**
     * Failure which occurred during execution of the associated request.
     *
     * If this response is not a failure this should be [Failure.none].
     */
    private val failure = builder.failure

    /*
     * Initialization ==============================================================================
     */

    /*
     * Functions ===================================================================================
     */

    /*
     */
    @Suppress("UNCHECKED_CAST")
    override fun <R : Request> getRequest(): R = request as R

    /*
     */
    override fun isSuccess() = !isFailure()

    /*
     */
    override fun getResult(): Result = result

    /*
     */
    override fun isFailure() = Failure.none() != failure

    /*
     */
    override fun getFailure(): Failure = failure

    /*
     */
    override fun toString(): String {
        val builder = StringBuilder(64)
        builder.append(TAG)
        builder.append("{request: ")
        builder.append(request)
        builder.append(", isSuccess: ")
        builder.append(isSuccess())
        builder.append(", result: ")
        builder.append(result)
        builder.append(", isFailure: ")
        builder.append(isFailure())
        builder.append(", failure: ")
        builder.append(failure)
        return builder.append("}").toString()
    }

    /*
     * Inner classes ===============================================================================
     */

    /**
     * A builder which may be used to create instances of [ResponseImpl].
     *
     * @param R Type of the result the response will carry.
     *
     * @author Martin Albedinsky
     *
     * @constructor Creates a new instance of BuilderImpl with given `request` the new response
     * will be created with.
     * @param request The request the new response to be associated with.
     */
    internal class Builder<R> internal constructor(
            /**
             * See [ResponseImpl.request].
             */
            val request: Request) : InstanceBuilder<ResponseImpl<R>> {

        /**
         * See [ResponseImpl.result].
         */
        @Suppress("UNCHECKED_CAST")
        internal var result = Result.empty() as R

        /**
         * See [ResponseImpl.failure].
         */
        internal var failure = Failure.none()

        /**
         * Specifies a result for the new response should represent a success response.
         *
         * @param result The desired result for the new response.
         * @return This builder to allow methods chaining.
         */
        fun result(result: R): Builder<R> = apply { this.result = result }

        /**
         * Specifies a failure for the new response which should represent a failure response.
         *
         * @param failure The desired failure for the new response.
         * @return This builder to allow methods chaining.
         */
        fun failure(failure: Failure): Builder<R> = apply { this.failure = failure }

        /*
         */
        override fun build() = ResponseImpl(this)
    }
}

==> arkhitekton-0.7.0-sources.jar: universum/studios/android/arkhitekton/interaction/ResponseImpl.kt <==
/*
 * *************************************************************************************************
 *                                 Copyright 2018 Universum Studios
 * *************************************************************************************************
 *                  Licensed under the Apache License, Version 2.0 (the "License")
 * -------------------------------------------------------------------------------------------------
 * You may not use this file except in compliance with the License. You may obtain a copy of the
 * License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied.
 *
 * See the License for the specific language governing permissions and limitations under the License.
 * *************************************************************************************************
 */
package universum.studios.android.arkhitekton.interaction

import universum.studios.android.arkhitekton.util.Error

/**
 * An implementation of [Response].
 *
 * @param T Type of the result value that this response can provide via [getValue] in case of success.
 *
 * @author Martin Albedinsky
 * @since 1.0
 *
 * @constructor Creates a new instance of ResponseImpl with the given `builder's` configuration.
 * @param request The request the new response to be associated with.
 * @param value The desired result value for the new successful response.
 * @param error The desired error for the new failure response.
 */
internal class ResponseImpl<out T> internal constructor(
        /**
         * The request associated with this response.
         */
        private val request: Request,
        /**
         * Result value which was produced by successful execution of the associated [request].
         *
         * If this response is a failure, this should be an EMPTY value.
         */
        value: T,
        /**
         * Error which occurred during execution of the associated request.
         *
         * If this response is a success this should be [Error.none].
         */
        error: Error) : BasicResult<T>(value, error), Response<T> {

    /*
     * Companion ===================================================================================
     */

    /*
	 * Interface ===================================================================================
	 */

    /*
     * Members =====================================================================================
     */

    /*
     * Initialization ==============================================================================
     */

    /*
     * Functions ===================================================================================
     */

    /*
     */
    @Suppress("UNCHECKED_CAST")
    override fun <R : Request> getRequest(): R = request as R

    /*
     */
    override fun toString(): String {
        val builder = StringBuilder(64)
        builder.append(Response::class.java.simpleName)
        builder.append("(request: ")
        builder.append("...")
        builder.append(", isSuccess: ")
        builder.append(isSuccess())
        builder.append(", value: ")
        builder.append(getValue())
        builder.append(", isFailure: ")
        builder.append(isFailure())
        builder.append(", error: ")
        builder.append(getError())
        return builder.append(")").toString()
    }

    /*
     * Inner classes ===============================================================================
     */
}
